@@ -1,10 +1,10 @@
 package File::Find::Object;
-$File::Find::Object::VERSION = '0.3.4';
+$File::Find::Object::VERSION = '0.3.5';
 use strict;
 use warnings;
 
 package File::Find::Object::DeepPath;
-$File::Find::Object::DeepPath::VERSION = '0.3.4';
+$File::Find::Object::DeepPath::VERSION = '0.3.5';
 use strict;
 use warnings;
 
@@ -67,7 +67,7 @@ sub _move_next
 }
 
 package File::Find::Object::TopPath;
-$File::Find::Object::TopPath::VERSION = '0.3.4';
+$File::Find::Object::TopPath::VERSION = '0.3.5';
 use parent 'File::Find::Object::PathComp';
 
 sub new
@@ -652,9 +652,13 @@ __END__
 
 =encoding UTF-8
 
+=head1 NAME
+
+File::Find::Object - An object oriented File::Find replacement
+
 =head1 VERSION
 
-version 0.3.4
+version 0.3.5
 
 =head1 SYNOPSIS
 
@@ -676,10 +680,6 @@ for another event and so get the next result.
 With File::Find::Object you can get the next file by calling the next()
 function, but setting a callback is still possible.
 
-=head1 NAME
-
-File::Find::Object - An object oriented File::Find replacement
-
 =head1 FUNCTIONS
 
 =head2 new
@@ -804,7 +804,7 @@ http://www.perlfoundation.org/legal/licenses/artistic-2_0.html
 
 3. At your option - any later version of either or both of these licenses.
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
@@ -841,14 +841,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=File-Find-Object>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/File-Find-Object>
-
-=item *
-
 CPAN Ratings
 
 The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
