@@ -1,5 +1,5 @@
 package File::Find::Object::Base;
-$File::Find::Object::Base::VERSION = '0.3.4';
+$File::Find::Object::Base::VERSION = '0.3.5';
 use strict;
 use warnings;
 
@@ -54,19 +54,19 @@ __END__
 
 =encoding UTF-8
 
+=head1 NAME
+
+File::Find::Object::Base - base class for File::Find::Object
+
 =head1 VERSION
 
-version 0.3.4
+version 0.3.5
 
 =head1 DESCRIPTION
 
 This is the base class for F::F::O classes. It only defines some accessors,
 and is for File::Find::Object's internal use.
 
-=head1 NAME
-
-File::Find::Object::Base - base class for File::Find::Object
-
 =head1 METHODS
 
 =head1 SEE ALSO
@@ -88,7 +88,7 @@ http://www.perlfoundation.org/legal/licenses/artistic-2_0.html
 
 3. At your option - any later version of either or both of these licenses.
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
@@ -125,14 +125,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=File-Find-Object>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/File-Find-Object>
-
-=item *
-
 CPAN Ratings
 
 The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
